@@ -3,7 +3,15 @@
 #![forbid(missing_docs)]
 #![doc = include_str!("../README.md")]
 
-pub use traits::ToXMLElement;
+mod builder;
+mod utils;
+mod xml;
+mod xmlcontent;
+mod xmlelement;
+mod xmlerror;
+mod xmlversion;
+
+pub use builder::XMLBuilder;
 pub use xml::XML;
 pub use xmlelement::XMLElement;
 pub use xmlerror::{Result, XMLError};
@@ -11,11 +19,3 @@ pub use xmlversion::XMLVersion;
 
 use utils::escape_str;
 use xmlcontent::XMLElementContent;
-
-mod traits;
-mod utils;
-mod xml;
-mod xmlcontent;
-mod xmlelement;
-mod xmlerror;
-mod xmlversion;
